function out = IID( soundSource, sampleRate, theta, headRadius, isLeft )

% function which simulates Interaural Intensity difference
%   of either the right or the left channel
%
% out = ITD( soundSource, sampleRate, theta, headradius, isLeft )
%
% soundSource is the sound source to be relocated
% sampleRate  is the sampling rate of the soundSource
% theta       is the angle to which the sound source is to be 
%             relocated
% headradius  is the radius of the listeners head
% isLeft      is (1/0) depending on if the left or right channel 
%             is to be created
% out         is the single channel Interaural Intensity
%             difference output 

nearEarLeft=0;
if theta < 0, %then left ear is the near ear
   nearEarLeft = 1; theta = abs( theta );
end;

c = 34300; tau = headRadius/(2*c); 
theta = theta*pi/180;
if theta >  pi/2, theta =  pi-theta; end
if theta < -pi/2, theta = -pi+theta; end

if ((nearEarLeft==1 & isLeft==0) | (nearEarLeft==0 & isLeft==1))
  
   theta = -0.9*sin(1.5*theta);
   feedback = [1, -exp(-1/(sampleRate*tau))];
   forward = [1, -exp(-1/(sampleRate*tau*(1+theta)))];
	gain = sum(forward)/sum(feedback);
   out = (filter(forward,feedback,soundSource(:))/gain)';
      
elseif ((nearEarLeft==0 & isLeft==0) | (nearEarLeft==1 & isLeft==1))
   
   theta = 2.2*sin(theta); 
   tau = tau/2; % zero at 2.6 kHz, pole higher
	forward = [1, -exp(-1/(sampleRate*tau))]; % zero an octave above left pole
	feedback = [1, -exp(-1/(sampleRate*tau/(1+theta)))]; % movable pole
   gain = sum(forward)/sum(feedback);
	out = (filter(forward,feedback,soundSource(:))/gain)';
   
end
