function [out] = pinna5(soundSource, fs, az)

%Pinna_model_5.m
%%This is the script to synthesize the HRIR model and convolve it with noise.
%For the listening tests, this code was reduced to a number of smaller
%%functions, and the convolution was done "on the fly" through a GUI. One
%important thing to note is that the script generates the delays in a continuous
%fashion which are later put into a discrete format by splitting the delay
%between adjacent samples.
% pinna_model_5.m
% script to model pinna and shoulder echos
%
% the azimuth is fixed at 55
%
% this version has three pinna echoes, as opposed to 2
% and does not use the original smoothing filter
% and instead uses the B'worth 1st order
%load pb_align.mat %loads aligned hrir
%hrir=hrir(:,37:72);
el=(-85:5:90)';
direct=ones(length(el),1);
% these numbers adjust the range of the sinusoidal response taken
% 0 to pi for tweak=1, etc.
%rd's
%D1=.85;
%D2=.35;
%pb's
D1=1;
D2=.5;
%nh's
%D1=1;
%D2=.5;
C1=0.5;
C2=0.5;
%shoulder coeff's
As=44;
Bs=12;
Cs=0.5;
Ds=0.6;
%generate delays
pinna_1=( cos(C1*az*pi/180)*sin(D1*(el+90)*pi/180) );
pinna_2=( cos(C2*az*pi/180)*sin(D2*(el+90)*pi/180) );
shld=round( As*(sin(Cs*az*pi/180)*cos(Ds*(el+90)*pi/180)) + Bs);
%put into "samples" quantity
A1=1; %1st echo slope
B1=2; %1st echo offset
A2=5; %2nd echo
B2=4;
A3=5; %3rd echo
B3=7;
A4=5; %4th echo
B4=11;
A5=5; %5th echo
B5=13;

% round down delay to nearest sample
pinna_1_fix=fix(pinna_1*A1 + B1);
pinna_2_fix=fix(pinna_2*A2) + B2;
pinna_3_fix=fix(pinna_2*A3) + B3;
pinna_4_fix=fix(pinna_2*A4) + B4;
pinna_5_fix=fix(pinna_2*A5) + B5;
%get the amount truncated due to rounding
pinna_1_mag=pinna_1*A1-(pinna_1_fix-B1);
pinna_2_mag=pinna_2*A2-(pinna_2_fix-B2);
pinna_3_mag=pinna_2*A3-(pinna_3_fix-B3);
pinna_4_mag=pinna_2*A4-(pinna_4_fix-B4);
pinna_5_mag=pinna_2*A5-(pinna_5_fix-B5);
% scale magnitude coeff's for echoes (a+b+c+d+e+f = 1)
a=1;
b=.5;
c=-1;
d=.5;
e=-.25;
f=.25;
% generate array with all the echoes
% and split and scale delays between adjacent samples

%synthrir=zeros(size(hrir,1)+1,size(hrir,2));
synthrir=zeros( 100, 35 );


for el=-85:5:90,
	idx=(el+85)/5+1;
	synthrir(shld(idx),idx)=0.2*cos(((idx-1)/35)*90*pi/180);
	synthrir(direct(idx),idx)=a;
	synthrir(pinna_1_fix(idx),idx)=b*(1-pinna_1_mag(idx));
	synthrir(pinna_1_fix(idx)+1,idx)=b*pinna_1_mag(idx);
	synthrir(pinna_2_fix(idx),idx)=c*(1-pinna_2_mag(idx));
	synthrir(pinna_2_fix(idx)+1,idx)=c*pinna_2_mag(idx);
	synthrir(pinna_3_fix(idx),idx)=d*(1-pinna_3_mag(idx));
	synthrir(pinna_3_fix(idx)+1,idx)=d*pinna_3_mag(idx);
	synthrir(pinna_4_fix(idx),idx)=e*(1-pinna_4_mag(idx));
	synthrir(pinna_4_fix(idx)+1,idx)=e*pinna_4_mag(idx);
	synthrir(pinna_5_fix(idx),idx)=f*(1-pinna_5_mag(idx));
	synthrir(pinna_5_fix(idx)+1,idx)=f*pinna_5_mag(idx);
end

%smoothing filter
[b,a]=butter(1,3000/(fs/2));
%synthrir=filters(b,a,synthrir);
synthrir=filter(b,a,synthrir);

% truncate to 32 samples long
synthrir=synthrir(1:32,:);
%hrir=hrir(1:32,:);
% up-sample for smoother image
for i=1:36,
   synthrir4(:,i)=interp(synthrir(:,i),4);
	%hrir4(:,i)=interp(hrir(:,i),4);
end

for i=1:36,
	synthrir(:,i)=decimate(synthrir4(:,i),4);
	%hrir(:,i)=decimate(hrir4(:,i),4);
end

tm=128/(4*fs/1000);
%hrir4=hrir4/max(max(abs(hrir4)));
synthrir4=synthrir4/max(max(abs(synthrir4)));
% plot images of the measured and modeled data
%figure(1)
%imagesc([],[0 tm],hrir4);
%grid on
%title('HRIR amplitude vs. time vs. elevation angle, near ear, azimuth=55');
%xlabel('Elevation Angle (degrees)')
%ylabel('Time (ms)')
%colormap(gray)
%colormap('jet')
%colorbar
%figure(2)
%imagesc([],[0 tm],synthrir4)
%grid on
%colormap(gray)
%colormap('jet')
%colorbar
%title('Model HRIR amplitude vs. time vs. elevation angle, near ear, azimuth=55');
%xlabel('Elevation Angle (degrees)')
%ylabel('Time (ms)')
%drawnow

% the remainder of the script convolves the model with noise and adds
% headshadow and ITD info
synthrir=[synthrir synthrir];
%fprintf('[Insert left & right ear headshadow into synthrir...');

for i=1:36,
	outcolumns = headfilter3(pi*az/180,[synthrir(:,i) synthrir(:,i+36)],0,fs);
	synthrir(:,i)=outcolumns(:,1);
	synthrir(:,i+36)=outcolumns(:,2);
%	fprintf('.');
%	if i==25
%		fprintf('\n');
%	end
end

%fprintf(']\n');
nsamples=size(synthrir,1);
%fprintf('[Generating Gaussian white noise ...]\n');
duration = .5; % duration in seconds
nduration = fix(duration*fs); % number of samples for duration



%g_noise=randn(1,nduration);
g_noise=soundSource';
%g_noise=g_noise/(6*max(abs(g_noise))); %scale the noise, use 6
%[b,a]=butter(1,1500/(fs/2),'high'); %HPF simulates ff response
%g_noise=filter(b,a,g_noise); % conv w/ meas'd ff response




%adjust nduration for the convolved signal
nduration=length(g_noise)+size(synthrir,1)-1;
%convolve the noise with the model
%fprintf('[Convolving Gaussian noise with HRTF ...');
model_hrir_snd=zeros(nduration,72);

for i=1:72,
	model_hrir_snd(:,i)=conv(g_noise,synthrir(:,i)')';
%	fprintf('.');
%	if i==25
%		fprintf('\n');
%	end
end

%fprintf(']\n');
%fprintf('[Adding artificial ITD ...');
a = 0.09; % head radius in meters
c = 343; % speed of sound in meters per second
ndelay=round( (a/c)*(az*pi/180 + sin(az*pi/180))*fs); %samples for ITD

for i=1:36,
	model_hrir_snd(ndelay+1:nduration,i)=model_hrir_snd(1:nduration-ndelay,i);
	model_hrir_snd(1:ndelay,i)=zeros(ndelay,1);
%	fprintf('.');
end;
%fprintf(']\n');


out = model_hrir_snd;
