function [out] = roomModel( soundSource, sampleRate, theta, headRadius, K, T )

% function which simulates a room using a sphereical head model and 
%   a room echo
%
% out = roomModel( soundSource, sampleRate, theta, headradius )
%
% soundSource is the sound source to be relocated
% sampleRate  is the sampling rate of the soundSource
% theta       is the angle to which the sound source is to be 
%             relocated
% headradius  is the radius of the listeners head
% K           is the gain of the Echo
% T           is the delay in msec
%
% out         is the stereo room Model
%

echo = roomEcho( soundSource, sampleRate, K, T );
soundSource = spherical( soundSource, sampleRate, theta, headRadius );

[Right, blah] = makeSameLength( soundSource(:,1)', echo' );
[Left , echo] = makeSameLength( soundSource(:,2)', echo' );
[Right, Left] = makeSameLength( Right, Left );

Left  = echo+Left;
Right = echo+Right;

out = [Right' ,Left' ];	% LEFT column comes out in RIGHT ear
